/*****************************************************************************
	AmyEdit - A GTKMM LaTeX Editor
	Copyright (C) 2004-2005 Rob Page
	email:  page <dot> rob <at> gmail <dot> com

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 *****************************************************************************/
#ifndef _EDITTABS_H
#define _EDITTABS_H

#include "PrefStruct.hh"

#include <gtkmm/notebook.h>
#include <gtkmm/scrolledwindow.h>
#include <gtksourceviewmm/sourceview.h>

#include <aspell.h>

class EditTabs: public Gtk::Notebook
{
	public:
		EditTabs();
		~EditTabs();

		void NewTab();
		void OpenTab();
		void OpenTab(Glib::ustring filename, bool open_if_not_found=false);
		bool SaveCurrentTab();
		bool SaveCurrentTabAs();
		void SaveAllTabs();
		bool CloseTab(int tab=-1);
		bool CloseAllTabs();

		void SaveCurrentTabAsTemplate();
		Glib::ustring Compile();
		bool SaveTmpTex();

		void Undo();
		void Redo();
		void CutText();
		void CopyText();
		void PasteText();
		void DeleteText();
		void FindNext();

		void SpellCheck();

		void SetWindowTitle();

		class Page:public Gtk::ScrolledWindow
		{
			public:
				Page(EditTabs *parent, Glib::RefPtr<Gtk::SourceBuffer> buffer=Glib::RefPtr<Gtk::SourceBuffer>());
				
				EditTabs *get_parent();
				Gtk::SourceView *get_child();
				Glib::RefPtr<Gtk::SourceBuffer> get_buffer();

				Glib::ustring filename;
				Gtk::Label *tablabel;
				Glib::ustring encoding;

			private:
				void on_close_me();
				void on_modified_changed();
				void on_changed();
				void on_mark_changed(Gtk::SourceBuffer::iterator iter,
				                     Glib::RefPtr<Gtk::SourceBuffer::Mark> mark);
				void on_preferences_update();

		};

	private:
		bool WriteTab();

		Glib::ustring GetRootFileName();
		Glib::ustring TabNameFromFile(Glib::ustring start);
		Glib::ustring GetUntitledTabName(Glib::ustring start);
		Glib::RefPtr<Gtk::SourceBuffer> is_buffer_open(Glib::ustring filename);

		void on_switching_page(GtkNotebookPage *page, guint number);
	public:
		Page *get_current_tab();
	private:
		Gtk::SourceView *get_current_view();

		void on_preferences_update();

};

#endif
