/*****************************************************************************
  AmyEdit - A GTKMM LaTeX Editor
  Copyright (C) 2004-2006 
  Rob Page email:  page <dot> rob <at> gmail <dot> com

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 *****************************************************************************/

#ifndef _PREFSTRUCT_HH
#define _PREFSTRUCT_HH

#include "Preferences.hh"
#include <glibmm/ustring.h>
#include <iostream>

class PrefStruct 
{
	protected:
		static PrefStruct* smInstance;

		PrefStruct();
		~PrefStruct();
		Glib::KeyFile config;

		/* TODO Shouldn't need this, just generate it when it is needed */
		Glib::KeyFile defaults;

	public:

		friend class Preferences;

		static PrefStruct* instance();
		static void goodnight();

		template <class T>
			T get(const Glib::ustring& group_name, const Glib::ustring& key) const
			{
				/* TODO nullpointer is a horrible hack */
				T* nullpointer = 0;
				try
				{
					return get(config, group_name, key, nullpointer);
				}
				catch(Glib::KeyFileError error)
				{
					std::cerr << "Group: " << group_name << ", Key: " << key
						<< " not found, trying to retrieve it from the"
						" default keyfile." << std::endl;
					return get(defaults, group_name, key, nullpointer);
				}
			}
	protected:
		Glib::ustring get(const Glib::KeyFile& keyfile, const Glib::ustring& group_name, const Glib::ustring& key, Glib::ustring* nullpointer) const;
		int get(const Glib::KeyFile& keyfile, const Glib::ustring& group_name, const Glib::ustring& key, int* nullpointer) const;
		bool get(const Glib::KeyFile& keyfile, const Glib::ustring& group_name, const Glib::ustring& key, bool* nullpointer) const;
		Glib::ArrayHandle<Glib::ustring> get(const Glib::KeyFile& keyfile, const Glib::ustring& group_name, const Glib::ustring& key, Glib::ArrayHandle<Glib::ustring>* nullpointer) const;
		
		
	public:
		void           set (const Glib::ustring& group_name, const Glib::ustring& key, const Glib::ustring& value);
		void           set (const Glib::ustring& group_name, const Glib::ustring& key, int value);
		void           set (const Glib::ustring& group_name, const Glib::ustring& key, bool value);

		void           set (const Glib::ustring& group_name, const Glib::ustring& key, Glib::ArrayHandle<Glib::ustring> values);

		Glib::ArrayHandle<Glib::ustring> get_keys(const Glib::ustring& group_name) const;

		void    remove_key (const Glib::ustring& group_name, const Glib::ustring& key);
		bool       has_key (const Glib::ustring& group_name, const Glib::ustring& key) const;
};

#endif  // _PREFSTRUCT_HH

