/*****************************************************************************
    AmyEdit - A GTKMM LaTeX Editor
    Copyright (C) 2004-2005 Rob Page
    email:  page <dot> rob <at> gmail <dot> com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*****************************************************************************/

#ifdef USE_PRECOMPILED_HEADERS
#  include "all.hh"
#endif

#include "config.h"

/*
 * Standard gettext macros.
 */
#ifdef ENABLE_NLS
#  include <libintl.h>
#  undef _
#  define _(String) dgettext (GETTEXT_PACKAGE, String)
#  ifdef gettext_noop
#    define N_(String) gettext_noop (String)
#  else
#    define N_(String) (String)
#  endif
#else
#  define textdomain(String) (String)
#  define gettext(String) (String)
#  define dgettext(Domain,Message) (Message)
#  define dcgettext(Domain,Message,Type) (Message)
#  define bindtextdomain(Domain,Directory) (Domain)
#  define _(String) (String)
#  define N_(String) (String)
#endif

#include "StatusBar.hh"
#include "Utils.hh"

sigc::signal1<void, int> signal_line_set;

StatusBar::StatusBar()
{
   
   set_homogeneous(false);

   pack_start(linenumber,Gtk::PACK_EXPAND_WIDGET);
   pack_start(ready,Gtk::PACK_SHRINK,2);
   setReady();
   setLine(-1);
   signal_line_set.connect(sigc::mem_fun(*this, &StatusBar::setLine));

}

StatusBar::~StatusBar()
{

}

void StatusBar::setReady(bool setting)
{
  if (setting)
    ready.set(Gtk::StockID("gtk-yes"),Gtk::ICON_SIZE_MENU);
  else
    ready.set(Gtk::StockID("gtk-no"),Gtk::ICON_SIZE_MENU);
  
}  

void StatusBar::setLine(int number)
{
  if (number < 0)
    linenumber.set_text(_("Line -"));
  else
    {
      linenumber.set_text(_("Line ")+Amy::itoa(number));
    }

}
