/*****************************************************************************
	AmyEdit - A GTKMM LaTeX Editor
	Copyright (C) 2004-2006 Rob Page
	email:  page <dot> rob <at> gmail <dot> com

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 *****************************************************************************/

#include "TextListModel.hh"

Gtk::TreeModel::Row TextListModel::append()
{
	return *(Gtk::ListStore::append());
}

Gtk::TreeModel::Row TextListModel::append(const Glib::ustring& text, bool allow_duplicates)
{
	Gtk::TreeModel::Row row;
	if (allow_duplicates || !(find_value(text)))
	{
		row = *(Gtk::ListStore::append());
		row[data.col[0]] = text;
	}
	return row;
}

void TextListModel::set_value(const Glib::ustring& text, Gtk::TreeModel::Row row, int column, bool allow_duplicates)
{
	if (allow_duplicates || !(find_value(text)))
		row[data.col[column]] = text;
}

Glib::ustring TextListModel::get_value(const TextListModel::iterator& iter, int column)
{
	return (*iter)[data.col[column]];
}

TextListModel::iterator TextListModel::find_value(const Glib::ustring& text, int column)
{
	TextListModel::iterator iter;
	for(iter =  children().begin();
	    iter != children().end();
		++iter)
	{
		Glib::ustring this_text = get_value(iter, column);

		if(this_text == text)
		{
			return iter;
		}
	}
	return iter;
}

const Gtk::TreeModelColumn<Glib::ustring> TextListModel::get_column(int column)
{
	return data.col[column];
}

Glib::RefPtr<TextListModel> TextListModel::create(int columns)
{
	return Glib::RefPtr<TextListModel>(new TextListModel(columns));
}

TextListModel::TextListColumn::~TextListColumn()
{
	delete[] col;
}

TextListModel::TextListModel(int columns) : data(columns)
{
	set_column_types(data);
}

TextListModel::TextListColumn::TextListColumn(int columns){
	col = new Gtk::TreeModelColumn<Glib::ustring>[columns];

	if (col!=NULL)
	{
		for (int i=0; i<columns; i++)
		{
			add(col[i]);
		}
	}
}

