/*****************************************************************************
    AmyEdit - A GTKMM LaTeX Editor
    Copyright (C) 2004-2005 Rob Page
    email:  page <dot> rob <at> gmail <dot> com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*****************************************************************************/

#ifndef _UTILS_HH
#define _UTILS_HH

#include <gtkmm/messagedialog.h>
#include "TextListModel.hh"

namespace Amy {

	enum DialogType { INFO, WARNING, ERROR, OK_CANCEL, YES_NO, MISC };

	int Message(Glib::ustring heading, Glib::ustring body=Glib::ustring(), DialogType type=INFO, bool add_cancel = false);

	class MiniDialog : public Gtk::MessageDialog
	{
		public:
			MiniDialog(Glib::ustring heading, Glib::ustring body=Glib::ustring(), DialogType type=INFO);
		private:
			static Gtk::MessageType getMessageType(DialogType type);
			static Gtk::ButtonsType getButtonType(DialogType type);
			Gtk::MessageType mtype;
			Gtk::ButtonsType btype;
	};
	
	Glib::ustring itoa(int num);

	/* store_full_path stores the full path in column 1,
	 * you'd better have two columns.... */
	void populate_text_list_model_from_dir(Glib::RefPtr<TextListModel> model, const std::string& dir, bool clear_list=false, bool store_full_path=false);

	void populate_text_list_model_from_list(Glib::RefPtr<TextListModel> model, const Glib::ArrayHandle<Glib::ustring>& list, bool clear_list=false);

	enum CommandType { LatexCommand, PreviewCommand};

	Glib::ustring get_command(CommandType type, const Glib::ustring& source_filename);
	
} /* namespace Amy */

#endif

