/* Gtk::SourceBuffer
 *
 * Base on gtksourceviewmm by Jae Jang
 * Copyright (C) 2005 Rob Page
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtktextbuffer.h>

#include <gtksourceview/gtksourcebuffer.h>
#include <gtksourceview/gtksourcelanguagesmanager.h>
#include <gtksourceviewmm/sourcebuffer.h>
#include <gtksourceviewmm/private/sourcebuffer_p.h>



namespace Glib
{

	Gtk::SourceBuffer* wrap(GtkSourceBuffer* object, bool take_copy)
	{
		return dynamic_cast<Gtk::SourceBuffer *> (Glib::wrap_auto ((GObject*)(object), take_copy));
	}


} /* namespace Glib */

namespace Gtk
{


	/* The *_Class implementation: */

	const Glib::Class& SourceBuffer_Class::init()
	{
		if(!gtype_) // create the GType if necessary
		{
			// Glib::Class has to know the class init function to clone custom types.
			class_init_func_ = &SourceBuffer_Class::class_init_function;

			// Create the wrapper type, with the same class/instance size as the base type.
			register_derived_type(gtk_source_buffer_get_type());

			// Add derived versions of interfaces, if the C type implements any interfaces:
		}

		return *this;
	}

	void SourceBuffer_Class::class_init_function(void* g_class, void* class_data)
	{
		BaseClassType *const klass = static_cast<BaseClassType*>(g_class);
		CppClassParent::class_init_function(klass, class_data);

	}

	Glib::ObjectBase* SourceBuffer_Class::wrap_new(GObject* o)
	{
		return new SourceBuffer((GtkSourceBuffer*)(o));

	}


	/* The implementation: */

	SourceBuffer::SourceBuffer(const Glib::ConstructParams& construct_params)
		:
		Gtk::TextBuffer(construct_params)
		{

		}

	SourceBuffer::SourceBuffer(GtkSourceBuffer* castitem)
		:
		Gtk::TextBuffer((GtkTextBuffer*)(castitem))
		{
		}

	SourceBuffer::~SourceBuffer()
	{
	}

	SourceBuffer::CppClassType SourceBuffer::sourcebuffer_class_; // initialize static member

	GType SourceBuffer::get_type()
	{
		return sourcebuffer_class_.init().get_type();
	}

	GType SourceBuffer::get_base_type()
	{
		return gtk_source_buffer_get_type();
	}


	SourceBuffer::SourceBuffer()
		:
		Glib::ObjectBase(0), //Mark this class as gtkmmproc-generated, rather than a custom class, to allow vfunc optimisations.
		Gtk::TextBuffer(Glib::ConstructParams(sourcebuffer_class_.init()))
		{
		}

	Glib::RefPtr <Gtk::SourceLanguagesManager> SourceBuffer::get_languages_manager(){
		static Glib::RefPtr<SourceLanguagesManager> lm;

		if (!lm){
			lm = Glib::RefPtr<SourceLanguagesManager>(new SourceLanguagesManager());
		}
		
		if (lm)
			lm->reference();

		return lm;

	}


	void SourceBuffer::set_check_brackets (bool check){
		gtk_source_buffer_set_check_brackets(gobj(), check);
	}

	bool SourceBuffer::get_check_brackets (){
		return gtk_source_buffer_get_check_brackets(gobj());
	}

	void SourceBuffer::set_bracket_match_style(GtkSourceTagStyle *style){
		gtk_source_buffer_set_bracket_match_style(gobj(), style);
	}

	void SourceBuffer::set_highlight (bool highlight){
		gtk_source_buffer_set_highlight(gobj(), highlight);
	}

	bool SourceBuffer::get_highlight (){
		return gtk_source_buffer_get_highlight(gobj());
	}

	void SourceBuffer::set_max_undo_levels(int max_undo_levels){
		gtk_source_buffer_set_max_undo_levels(gobj(), max_undo_levels);
	}

	int SourceBuffer::get_max_undo_levels(){
		return gtk_source_buffer_get_max_undo_levels(gobj());
	}

	void SourceBuffer::set_language (Glib::RefPtr<SourceLanguage> language){
		gtk_source_buffer_set_language(gobj(), language->gobj());
	}

	Glib::RefPtr<SourceLanguage> SourceBuffer::get_language(){
		return Glib::wrap((GtkSourceLanguage*)gtk_source_buffer_get_language(gobj()));
	}

	void SourceBuffer::set_escape_char (gunichar escape_char){
		gtk_source_buffer_set_escape_char(gobj(),escape_char);
	}
	gunichar SourceBuffer::get_escape_char (){
		return gtk_source_buffer_get_escape_char(gobj());
	}

	bool SourceBuffer::can_undo(){
		return gtk_source_buffer_can_undo(gobj());
	}

	bool SourceBuffer::can_redo(){
		return gtk_source_buffer_can_redo(gobj());
	}

	void SourceBuffer::undo(){
		gtk_source_buffer_undo(gobj());
	}
	void SourceBuffer::redo(){
		gtk_source_buffer_redo(gobj());
	}

	void SourceBuffer::begin_not_undoable_action(){
		gtk_source_buffer_begin_not_undoable_action(gobj());
	}

	void SourceBuffer::end_not_undoable_action(){
		gtk_source_buffer_end_not_undoable_action(gobj());
	}

} // namespace Gtk
