/* Gtk::SourceView
 *
 * Copyright 2004-2005 Jae Jang
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtktextview.h>

#include <gtksourceview/gtksourceview.h>
#include <gtksourceviewmm/sourceview.h>
#include <gtksourceviewmm/private/sourceview_p.h>



namespace Glib
{

Gtk::SourceView* wrap(GtkSourceView* object, bool take_copy)
{
    return dynamic_cast<Gtk::SourceView *> (Glib::wrap_auto ((GObject*)(object), take_copy));
}


} /* namespace Glib */

namespace Gtk
{


/* The *_Class implementation: */

const Glib::Class& SourceView_Class::init()
{
    if(!gtype_) // create the GType if necessary
    {
        // Glib::Class has to know the class init function to clone custom types.
        class_init_func_ = &SourceView_Class::class_init_function;

        // Create the wrapper type, with the same class/instance size as the base type.
        register_derived_type(gtk_source_view_get_type());

        // Add derived versions of interfaces, if the C type implements any interfaces:
    }

    return *this;
}

void SourceView_Class::class_init_function(void* g_class, void* class_data)
{
    BaseClassType *const klass = static_cast<BaseClassType*>(g_class);
    CppClassParent::class_init_function(klass, class_data);

}

Glib::ObjectBase* SourceView_Class::wrap_new(GObject* o)
{
    return manage(new SourceView((GtkSourceView*)(o)));

}


/* The implementation: */

SourceView::SourceView(const Glib::ConstructParams& construct_params)
        :
        Gtk::TextView(construct_params)
{

}

SourceView::SourceView(GtkSourceView* castitem)
        :
        Gtk::TextView((GtkTextView*)(castitem))
{
}

SourceView::~SourceView()
{
    destroy_();
}

SourceView::CppClassType SourceView::sourceview_class_; // initialize static member

GType SourceView::get_type()
{
    return sourceview_class_.init().get_type();
}

GType SourceView::get_base_type()
{
    return gtk_source_view_get_type();
}

SourceView::SourceView(Glib::RefPtr<SourceBuffer> buffer)
	:
	Glib::ObjectBase(0),
	Gtk::TextView(Glib::ConstructParams(sourceview_class_.init()))
{
	set_buffer(buffer);
}

SourceView::SourceView()
        :
        Glib::ObjectBase(0), //Mark this class as gtkmmproc-generated, rather than a custom class, to allow vfunc optimisations.
        Gtk::TextView(Glib::ConstructParams(sourceview_class_.init()))
{
    SourceBuffer *buffer = new SourceBuffer();
    set_buffer(Glib::RefPtr<SourceBuffer>(buffer));
}


void SourceView::set_buffer(const Glib::RefPtr<SourceBuffer>& buffer)
{
  TextView::set_buffer(buffer);
}

Glib::RefPtr<SourceBuffer> SourceView::get_buffer()
{
  return Glib::RefPtr<Gtk::SourceBuffer>::cast_static(TextView::get_buffer());
}



void SourceView::set_show_line_numbers 	(bool show)
{
    gtk_source_view_set_show_line_numbers(gobj(), show);
}

bool SourceView::get_show_line_numbers 	()
{
    return gtk_source_view_get_show_line_numbers(gobj());
}
void SourceView::set_show_line_markers 	(bool show)
{
    gtk_source_view_set_show_line_markers(gobj(), show);
}

bool SourceView::get_show_line_markers 	()
{
    return gtk_source_view_get_show_line_markers(gobj());
}

void 		 SourceView::set_tabs_width 	(int            width)
{
    gtk_source_view_set_tabs_width(gobj(), width);
}

int            SourceView::get_tabs_width         ()
{
    return gtk_source_view_get_tabs_width(gobj());
}

void		 SourceView::set_auto_indent 	(bool         enable)
{
    gtk_source_view_set_auto_indent(gobj(),enable);
}

bool	 SourceView::get_auto_indent 	()
{
    return gtk_source_view_get_auto_indent(gobj());
}

void SourceView::set_insert_spaces_instead_of_tabs 	( bool         enable)
{
    gtk_source_view_set_insert_spaces_instead_of_tabs(gobj(), enable);
}

bool	 SourceView::get_insert_spaces_instead_of_tabs 	()
{
    return gtk_source_view_get_insert_spaces_instead_of_tabs(gobj());
}

void		 SourceView::set_show_margin 	(bool         show)
{
    gtk_source_view_set_show_margin(gobj(), show);
}
bool 	 SourceView::get_show_margin 	()
{
    return gtk_source_view_get_show_margin(gobj());
}

void		 SourceView::set_margin 		(int            margin)
{
    gtk_source_view_set_margin(gobj(), margin);
}

int		 SourceView::get_margin 		()
{
    return gtk_source_view_get_margin(gobj());
}

void             SourceView::set_marker_pixbuf      (const Glib::ustring &marker_type,
        const Glib::RefPtr<Gdk::Pixbuf>&       pixbuf)
{
    gtk_source_view_set_marker_pixbuf(gobj(), marker_type.c_str(), Glib::unwrap(pixbuf));
}

Glib::RefPtr<const Gdk::Pixbuf> SourceView::get_marker_pixbuf      (const Glib::ustring &marker_type)
{
    Glib::RefPtr<Gdk::Pixbuf> retvalue = Glib::wrap(gtk_source_view_get_marker_pixbuf(gobj(), marker_type.c_str()));

    if(retvalue)
        retvalue->reference(); //The function does not do a ref for us.
    return retvalue;
}

void		  SourceView::set_smart_home_end	( bool         enable)
{
    gtk_source_view_set_smart_home_end(gobj(), enable);
}

bool	  SourceView::get_smart_home_end	()
{
    return gtk_source_view_get_smart_home_end(gobj());
}

const Glib::SignalProxyInfo SourceView_signal_undo =
    {
        "undo",
        (GCallback) &Glib::SignalProxyNormal::slot0_void_callback,
        (GCallback) &Glib::SignalProxyNormal::slot0_void_callback
    };

const Glib::SignalProxyInfo SourceView_signal_redo =
    {
        "redo",
        (GCallback) &Glib::SignalProxyNormal::slot0_void_callback,
        (GCallback) &Glib::SignalProxyNormal::slot0_void_callback
    };

Glib::SignalProxy0< void > SourceView::signal_undo()
{
    return Glib::SignalProxy0< void >(this, &SourceView_signal_undo);
}

Glib::SignalProxy0< void > SourceView::signal_redo()
{
    return Glib::SignalProxy0< void >(this, &SourceView_signal_redo);
}

} // namespace Gtk
