#ifndef _GTKSOURCEVIEWMM_SOURCEVIEW_H
#define _GTKSOURCEVIEWMM_SOURCEVIEW_H

#include <glibmm.h>
#include <gdkmm/pixbuf.h>
/* sourceview.h
 * 
 * Copyright (C) 2004-2005 Jae Jang
 * Copyright (C) 2005 Rob Page
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtkmm/textview.h>
#include <gtksourceviewmm/sourcebuffer.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
typedef struct _GtkSourceView GtkSourceView;
typedef struct _GtkSourceViewClass GtkSourceViewClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


namespace Gtk
    { class SourceView_Class; } // namespace Gtk
namespace Gtk
{

class SourceView : public Gtk::TextView
{
public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
    typedef SourceView CppObjectType;
    typedef SourceView_Class CppClassType;
    typedef GtkSourceView BaseObjectType;
    typedef GtkSourceViewClass BaseClassType;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

    virtual ~SourceView();

#ifndef DOXYGEN_SHOULD_SKIP_THIS

private:
    friend class SourceView_Class;
    static CppClassType sourceview_class_;

    // noncopyable
    SourceView(const SourceView&);
    SourceView& operator=(const SourceView&);

protected:
    explicit SourceView(const Glib::ConstructParams& construct_params);
    explicit SourceView(GtkSourceView* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
    static GType get_type()      G_GNUC_CONST;
    static GType get_base_type() G_GNUC_CONST;
#endif

    ///Provides access to the underlying C GtkObject.
    GtkSourceView*       gobj()       { return reinterpret_cast<GtkSourceView*>(gobject_); }

    ///Provides access to the underlying C GtkObject.
    const GtkSourceView* gobj() const { return reinterpret_cast<GtkSourceView*>(gobject_); }


public:
    //C++ methods used to invoke GTK+ virtual functions:

protected:
    //GTK+ Virtual Functions (override these to change behaviour):

private:

public:

	SourceView(Glib::RefPtr<SourceBuffer>buffer);
    SourceView();

    void set_buffer(const Glib::RefPtr<SourceBuffer>& buffer);
    Glib::RefPtr<SourceBuffer> get_buffer();

    void 	 set_show_line_numbers 	(bool show);
    bool 	 get_show_line_numbers 	();

    void 		set_show_line_markers  (bool show);
    bool	 get_show_line_markers  ();
    void 		 set_tabs_width 	(int width);
    int         get_tabs_width         ();
    void		 set_auto_indent 	(bool enable);
    bool	 get_auto_indent 	();
    void		 set_insert_spaces_instead_of_tabs 	( bool enable);
    bool	 get_insert_spaces_instead_of_tabs 	();
    void		 set_show_margin 	(bool show);
    bool 	 get_show_margin 	();
    void		set_margin 		(int margin);
    int		 get_margin 		();
    void     set_marker_pixbuf      (const Glib::ustring &marker_type,
                  const Glib::RefPtr<Gdk::Pixbuf>&pixbuf);
    Glib::RefPtr<const Gdk::Pixbuf> 
                get_marker_pixbuf      (const Glib::ustring &marker_type);


    void	 set_smart_home_end	( bool enable);
    bool	 get_smart_home_end	();

    Glib::SignalProxy0< void > signal_undo();
    Glib::SignalProxy0< void > signal_redo();

};

} // namespace Gtk


namespace Glib
{
Gtk::SourceView* wrap(GtkSourceView* object, bool take_copy = false);
}
#endif 
